@@ -35,8 +35,6 @@ namespace GLib {
 		protected System.Type element_type = null;
 
 		abstract internal IntPtr NthData (uint index);
-		abstract internal IntPtr GetData (IntPtr current);
-		abstract internal IntPtr Next (IntPtr current);
 		abstract internal int Length (IntPtr list);
 		abstract internal void Free (IntPtr list);
 		abstract internal IntPtr Append (IntPtr current, IntPtr raw);
@@ -185,7 +183,7 @@ namespace GLib {
 		[DllImport ("libglib-2.0-0.dll")]
 		static extern void g_free (IntPtr item);
 
-		[DllImport ("libglib-2.0-0.dll")]
+		[DllImport ("libgobject-2.0-0.dll")]
 		static extern void g_object_unref (IntPtr item);
 
 		public void Empty ()
@@ -203,6 +201,18 @@ namespace GLib {
 				FreeList ();
 		}
 
+		IntPtr GetData (IntPtr current)
+		{
+			// data field is at offset 0 for GList and GSList
+			return Marshal.ReadIntPtr (current);
+		}
+
+		IntPtr Next (IntPtr current)
+		{
+			// next field follows gpointer data field for GList and GSList
+			return Marshal.ReadIntPtr (current, IntPtr.Size);
+		}
+
 		private class ListEnumerator : IEnumerator
 		{
 			private IntPtr current = IntPtr.Zero;
